Name:           elog
Version:        3.1.0
Release:        3%{?dist}
Summary:        Weblog server and client

License:        GPLv2
URL:			https://midas.psi.ch/elog/
Source0:        http://midas.psi.ch/elog/download/tar/elog-3.1.0-2.tar.gz
Source1:		https://tc01.fedorapeople.org/elog/elogd.service
Patch0:			https://tc01.fedorapeople.org/elog/elog-makefile-elogdir.patch

BuildRequires:	glibc-devel, openssl-devel, systemd, ckeditor, dos2unix
Requires:		ckeditor

Requires(pre):	shadow-utils

%description
ELOG is part of a family of applications known as weblogs. Their general
purpose is:

1. To make it easy for people to put information online in a chronological
fashion, in the form of short, time-stamped text messages ("entries") with
optional HTML markup for presentation, and optional file attachments
(images, archives, etc.)

2. To make it easy for other people to access this information through a
Web interface, browse entries, search, download files, and optionally add,
update, delete or comment on entries.

ELOG is a remarkable implementation of a weblog in at least two respects:

1. Its simplicity of use: you don't need to be a seasoned server operator
and/or an experimented database administrator to run ELOG ; one executable
file (under Unix or Windows), a simple configuration text file, and it works.
No Web server or relational database required. It is also easy to translate
the interface to the appropriate language for your users.

2. Its versatility: through its single configuration file, ELOG can be made
to display an infinity of variants of the weblog concept. There are options
for what to display, how to display it, what commands are available and to
whom, access control, etc. Moreover, a single server can host several
weblogs, and each weblog can be totally different from the rest.

%prep
%setup -q
%patch0 -p1
# Various fixes; remove executable bits, remove bundled ckeditor.
rm -rf scripts/ckeditor

cd scripts && find . -type f -print0 | xargs -0 chmod a-x && cd ..
chmod a-x COPYING

rm doc/index.html~
cd doc && find . -type f -print0 | xargs -0 chmod a-x && cd ..
dos2unix doc/strftime.txt

%build
make %{?_smp_mflags}

%install
rm -rf %{buildroot}

# This makefile needs a fair amount of massaging to do the right thing.
# Hence the above patch.
make install ROOT=%{buildroot} PREFIX=%{_usr} MANDIR=%{buildroot}%{_mandir} ELOGDIR=%{buildroot}%{_datadir}/elog
rm %{buildroot}%{_initddir}/elogd

# Move the configuration file to the right place.
mv %{buildroot}%{_datadir}/elog/elogd.cfg %{buildroot}%{_sysconfdir}/

# Land the systemd initscript.
mkdir -p %{buildroot}%{_unitdir}
cp %SOURCE1 %{buildroot}%{_unitdir}

# Create elog user/group.
%pre
getent group elog > /dev/null || groupadd -r elog
getent passwd elog  > /dev/null || \
    useradd -r -g elog -d /usr/share/elog -s /sbin/nologin \
    -c "ELOG logbook daemon user" elog
exit 0

%post
chown -R elog:elog %{_datadir}/elog/

# replace bundled ckeditor with a symlink.
ln -s %{_datadir}/ckeditor scripts/ckeditor

%files
# These two could possibly be bundled off into an elog-client subpackage or something.
%{_bindir}/elog
%{_mandir}/man1/elog.1*

%{_bindir}/elconv
%{_sbindir}/elogd
%{_datadir}/elog/
%{_mandir}/man1/elconv.1*
%{_mandir}/man8/elogd.8*
%{_unitdir}/elogd.service

# Configuration for elogd.
%config(noreplace) %{_sysconfdir}/elogd.cfg

%doc README doc/
%license COPYING

%changelog
* Wed Jul 8 2015 Ben Rosser <rosser.bjr@gmail.com> 3.1.0-3
- Removed bundled ckeditor, replaced with an absolute symlink
- Moved configuration file to /etc/elogd.cfg.
- Created elog user/group so that the script works successfully.

* Tue Jul 7 2015 Ben Rosser <rosser.bjr@gmail.com> 3.1.0-2
- Removed initscript, replaced it with a systemd service file.

* Tue Jul 7 2015 Ben Rosser <rosser.bjr@gmail.com> 3.1.0-1
- Created initial package.
- Applied a patch to the makefile to make everything work correctly.
